<?xml version="1.0"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
<xsl:output method="xml" version="1.0" encoding="utf-8" doctype-system="cimv20.dtd" indent="yes"/>

<xsl:param name="lang">US</xsl:param>
<xsl:variable name="defaultLang">US</xsl:variable>

<xsl:template match="odd[@this]">
<CIM CIMVERSION="2.0" DTDVERSION="2.0">
  <MESSAGE id="1" PROTCOLVERSION="1.0">
  <MULTIREQ>
    <SIMPLEREQ>
       <IMTEHODCALL NAME="CreateInstance">
         <LOCALNAMESPACEPATH>
           <NAMESPACE NAME="root"/>
           <NAMESPACE NAME="cimv2"/>
         </LOCALNAMESPACEPATH>
         <IPARAMVALUE NAME="NewInstance">
           <INSTANCE CLASSNAME="IBMPSG_SystemUpdateElement">
             <xsl:apply-templates select="title"/>
             <PROPERTY NAME="SoftwareElementID" TYPE="string"><VALUE><xsl:value-of select="name/@id"/></VALUE></PROPERTY>
             <PROPERTY NAME="SoftwareElementState" TYPE="uint16"><VALUE>1</VALUE></PROPERTY>
             <PROPERTY NAME="TargetOperatingSystem" TYPE="uint16"><VALUE>58</VALUE></PROPERTY>
             <PROPERTY NAME="Version" TYPE="string"><VALUE><xsl:value-of select="version/@id"/></VALUE></PROPERTY>
             <PROPERTY.ARRAY NAME="applicableMachineTypes" TYPE="uint16"><VALUE.ARRAY>
               <xsl:apply-templates select="applicableMachineTypes"/>
             </VALUE.ARRAY></PROPERTY.ARRAY>
             <PROPERTY.ARRAY NAME="applicableOperatingSystems" TYPE="string"><VALUE.ARRAY>
               <xsl:apply-templates select="applicableOperatingSystems"/>
             </VALUE.ARRAY></PROPERTY.ARRAY>
             <PROPERTY NAME="buildNumber" TYPE="string"><VALUE><xsl:value-of select="buildNumber/@id"/></VALUE></PROPERTY>
             <PROPERTY NAME="description" TYPE="string"><VALUE></VALUE></PROPERTY>
             <PROPERTY NAME="installCommandLine" TYPE="string"><VALUE><xsl:value-of select="ucd/commandLines/install"/></VALUE></PROPERTY>
             <!-- <PROPERTY NAME="installationNotes" TYPE="string"><VALUE><xsl:value-of select="installNotes/description[@id='US']"/></VALUE></PROPERTY> -->
             <xsl:apply-templates select="installNotes"/>
             <PROPERTY NAME="languageEdition" TYPE="string"><VALUE><xsl:apply-templates select="language"/></VALUE></PROPERTY>
             <PROPERTY NAME="manufacturer" TYPE="string"><VALUE>IBM</VALUE></PROPERTY>
             <PROPERTY NAME="rebootRequired" TYPE="uint8"><VALUE><xsl:value-of select="rebootRequired/@number"/></VALUE></PROPERTY>
             <PROPERTY NAME="regions" TYPE="string"><VALUE></VALUE></PROPERTY>
             <PROPERTY NAME="releaseDate" TYPE="datetime"><VALUE><xsl:value-of select="releaseDate/@id"/></VALUE></PROPERTY>
             <xsl:apply-templates select="revisionHistory"/>
             <PROPERTY NAME="severity" TYPE="uint8"><VALUE><xsl:value-of select="severity/@level"/></VALUE></PROPERTY>
             <PROPERTY NAME="installDirectory" TYPE="string"><VALUE>.</VALUE></PROPERTY>
             <xsl:apply-templates select="ucd/commandLines"/>
           </INSTANCE>
         </IPARAMVALUE>
       </IMTEHODCALL>
    </SIMPLEREQ>
  </MULTIREQ>
  </MESSAGE>

</CIM>

</xsl:template>

<!-- Template for applicable machine types -->
<xsl:template match="applicableMachineTypes">
  <xsl:for-each select="mtDesc">
    <VALUE><xsl:value-of select="."/></VALUE>
  </xsl:for-each>
</xsl:template>

<!-- Template for applicable operating systems -->
<xsl:template match="applicableOperatingSystems">
  <xsl:for-each select="osDesc">
    <VALUE><xsl:value-of select="."/></VALUE>
  </xsl:for-each>
</xsl:template>

<!-- Template for supported languages -->
<xsl:template match="language">
  <xsl:for-each select="supported/@id">
    <xsl:value-of select="."/>
      <xsl:if test="position() != last()">
        <xsl:text> </xsl:text>
      </xsl:if>
  </xsl:for-each> 
</xsl:template>

<!-- Template for command lines -->
<xsl:template match="ucd/commandLines">
  <xsl:choose>
    <xsl:when test="string(extract)">
       <PROPERTY NAME="unattendedInstallCommandLine" TYPE="string"><VALUE><xsl:value-of select="extract"/>;<xsl:value-of select="unattendedInstall"/></VALUE></PROPERTY> 
    </xsl:when>
    <xsl:otherwise>
       <PROPERTY NAME="unattendedInstallCommandLine" TYPE="string"><VALUE><xsl:value-of select="unattendedInstall"/></VALUE></PROPERTY>
    </xsl:otherwise>
  </xsl:choose>
  <PROPERTY NAME="unattendedUninstallCommandLine" TYPE="string"><VALUE><xsl:value-of select="unattendedUninstall"/></VALUE></PROPERTY>
  <PROPERTY NAME="uninstallCommandLine" TYPE="string"><VALUE><xsl:value-of select="uninstall"/></VALUE></PROPERTY>
</xsl:template>

<!-- Template for title -->
<xsl:template match="title">
  <xsl:choose>
    <xsl:when test="string(description[@id=$lang])">
        <PROPERTY NAME="Name" TYPE="string"><VALUE><xsl:value-of select="description[@id=$lang]"/></VALUE></PROPERTY>
    </xsl:when>
    <xsl:otherwise>
        <PROPERTY NAME="Name" TYPE="string"><VALUE><xsl:value-of select="description[@id=$defaultLang]"/></VALUE></PROPERTY>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<!-- Template for revision history -->
<xsl:template match="revisionHistory">
  <xsl:choose>
    <xsl:when test="string(description[@id=$lang])">
       <PROPERTY NAME="revisionHistory" TYPE="string"><VALUE><xsl:value-of select="description[@id=$lang]"/></VALUE></PROPERTY>
    </xsl:when>
    <xsl:otherwise>
       <PROPERTY NAME="revisionHistory" TYPE="string"><VALUE><xsl:value-of select="description[@id=$defaultLang]"/></VALUE></PROPERTY>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<!-- Template for installation notes -->
<xsl:template match="installNotes">
  <xsl:choose>
    <xsl:when test="string(description[@id=$lang])">
       <PROPERTY NAME="installationNotes" TYPE="string"><VALUE><xsl:value-of select="description[@id=$lang]"/></VALUE></PROPERTY>
    </xsl:when>
    <xsl:otherwise>
       <PROPERTY NAME="installationNotes" TYPE="string"><VALUE><xsl:value-of select="description[@id=$defaultLang]"/></VALUE></PROPERTY>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>


</xsl:stylesheet>


